@@ -25,6 +25,7 @@ def _gtk_init(icon=None):
     import pygtk
     pygtk.require('2.0')
     import gtk
+    import gobject
 
     import quodlibet.stock
     quodlibet.stock.init()
@@ -46,7 +47,8 @@ def _gtk_init(icon=None):
                   "your $BROWSER variable, or make sure "
                   "/usr/bin/sensible-browser exists.")).run()
 
-    gtk.about_dialog_set_url_hook(website_wrap)
+    # only works with a running main loop
+    gobject.idle_add(gtk.about_dialog_set_url_hook, website_wrap)
 
 def _gettext_init():
     try: locale.setlocale(locale.LC_ALL, '')
@@ -179,6 +181,7 @@ def init_backend(backend, librarian):
 def enable_periodic_save(save_library):
     import quodlibet.library
     from quodlibet.util import copool
+    from quodlibet import config
 
     timeout = 5 * 60 * 1000  # 5 minutes
 
@@ -264,8 +267,9 @@ def main(window):
             if gtk.main_iteration(False):
                 print_d("Quit GTK: Timeout occured, force quit.")
                 break
+        else:
+            gtk.main_quit()
 
-        gtk.main_quit()
         print_d("Quit GTK: done.")
 
     window.connect('destroy', quit_gtk)
