@@ -8,6 +8,7 @@
 import gtk
 import gobject
 import os
+import threading
 
 import pygst
 pygst.require("0.10")
@@ -291,6 +292,7 @@ class GStreamerPlayer(BasePlayer):
 
     def __message(self, bus, message, librarian):
         if message.type == gst.MESSAGE_EOS:
+            print_d("Stream EOS")
             if not self._in_gapless_transition:
                 self._source.next_ended()
             self._end(False)
@@ -313,6 +315,7 @@ class GStreamerPlayer(BasePlayer):
             # which should trigger shortly after this.
             if USE_TRACK_CHANGE and self._in_gapless_transition and \
                 name == "playbin2-stream-changed":
+                    print_d("Stream changed")
                     self._end(False)
 
             if pbutils and name.startswith('missing-'):
@@ -326,16 +329,27 @@ class GStreamerPlayer(BasePlayer):
         return True
 
     def __about_to_finish(self, pipeline):
+        print_d("About to finish")
+        # this can trigger twice, see issue 987
+        if self._in_gapless_transition:
+            return
         self._in_gapless_transition = True
 
-        # uri has to be set in this thread, so idle_add doesn't work
-        gtk.gdk.threads_enter()
-        self._source.next_ended()
-        song = self._source.current
-        gtk.gdk.threads_leave()
+        def change_in_main_loop(event, source):
+            source.next_ended()
+            event.set()
 
-        if song and self.bin:
-            self.bin.set_property('uri', song("~uri"))
+        # push in the main loop and wait for it to finish
+        event = threading.Event()
+        gobject.idle_add(change_in_main_loop, event, self._source,
+                         priority=gobject.PRIORITY_HIGH)
+        event.wait()
+
+        song = self._source.current
+        bin = self.bin
+
+        if song and bin:
+            bin.set_property('uri', song("~uri"))
 
         if not USE_TRACK_CHANGE:
             gobject.idle_add(self._end, False)
@@ -473,6 +487,7 @@ class GStreamerPlayer(BasePlayer):
                 self.emit('seek', self.song, pos)
 
     def _end(self, stopped, stop=False):
+        print_d("End song")
         song, info = self.song, self.info
 
         # set the new volume before the signals to avoid delays
@@ -493,6 +508,7 @@ class GStreamerPlayer(BasePlayer):
             self.song = self.info = self._source.current
         self.emit('song-started', self.song)
 
+        print_d("Next song")
         if self.song is not None:
             if not self._in_gapless_transition:
                 self.volume = self.volume
@@ -600,11 +616,6 @@ def init(librarian):
     if flu and mad:
         flu.set_rank(min(flu.get_rank(), max(mad.get_rank() - 1, 0)))
 
-    # doesn't provide seeking but has a high rank -> blacklist
-    # (this is no core plugin)
-    mpg123 = gst.element_factory_find("mpg123")
-    if mpg123: mpg123.set_rank(0)
-
     if gst.element_make_from_uri(
         gst.URI_SRC,
         "file:///fake/path/for/gst", ""):
